# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/group_mapping_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import group_mapping_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_group__mapping__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/organizationmanager/v1/group_mapping_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x37yandex/cloud/organizationmanager/v1/group_mapping.proto\x1a\x1dyandex/cloud/validation.proto\"=\n\x16GetGroupMappingRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"c\n\x17GetGroupMappingResponse\x12H\n\rgroup_mapping\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.organizationmanager.v1.GroupMapping\"W\n\x19\x43reateGroupMappingRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08J\x04\x08\x02\x10\x03\"3\n\x1a\x43reateGroupMappingMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\x82\x01\n\x19UpdateGroupMappingRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"3\n\x1aUpdateGroupMappingMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"@\n\x19\x44\x65leteGroupMappingRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x1a\x44\x65leteGroupMappingMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\xb6\x01\n\x1eUpdateGroupMappingItemsRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12i\n\x19group_mapping_item_deltas\x18\x04 \x03(\x0b\x32:.yandex.cloud.organizationmanager.v1.GroupMappingItemDeltaB\n\x82\xc8\x31\x06\x31-1000J\x04\x08\x02\x10\x04\"\xe6\x01\n\x15GroupMappingItemDelta\x12\x43\n\x04item\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.GroupMappingItem\x12Q\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32\x41.yandex.cloud.organizationmanager.v1.GroupMappingItemDelta.Action\"5\n\x06\x41\x63tion\x12\x16\n\x12\x41\x43TION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\"8\n\x1fUpdateGroupMappingItemsMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\x80\x01\n\x1fUpdateGroupMappingItemsResponse\x12]\n\x19group_mapping_item_deltas\x18\x04 \x03(\x0b\x32:.yandex.cloud.organizationmanager.v1.GroupMappingItemDelta\"\x9e\x01\n\x1cListGroupMappingItemsRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x8c\x01\n\x1dListGroupMappingItemsResponse\x12R\n\x13group_mapping_items\x18\x01 \x03(\x0b\x32\x35.yandex.cloud.organizationmanager.v1.GroupMappingItem\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xd0\x07\n\x13GroupMappingService\x12\x80\x01\n\x03Get\x12;.yandex.cloud.organizationmanager.v1.GetGroupMappingRequest\x1a<.yandex.cloud.organizationmanager.v1.GetGroupMappingResponse\x12\x9b\x01\n\x06\x43reate\x12>.yandex.cloud.organizationmanager.v1.CreateGroupMappingRequest\x1a!.yandex.cloud.operation.Operation\".\xb2\xd2**\n\x1a\x43reateGroupMappingMetadata\x12\x0cGroupMapping\x12\x9b\x01\n\x06Update\x12>.yandex.cloud.organizationmanager.v1.UpdateGroupMappingRequest\x1a!.yandex.cloud.operation.Operation\".\xb2\xd2**\n\x1aUpdateGroupMappingMetadata\x12\x0cGroupMapping\x12\xa4\x01\n\x06\x44\x65lete\x12>.yandex.cloud.organizationmanager.v1.DeleteGroupMappingRequest\x1a!.yandex.cloud.operation.Operation\"7\xb2\xd2*3\n\x1a\x44\x65leteGroupMappingMetadata\x12\x15google.protobuf.Empty\x12\x92\x01\n\tListItems\x12\x41.yandex.cloud.organizationmanager.v1.ListGroupMappingItemsRequest\x1a\x42.yandex.cloud.organizationmanager.v1.ListGroupMappingItemsResponse\x12\xbd\x01\n\x0bUpdateItems\x12\x43.yandex.cloud.organizationmanager.v1.UpdateGroupMappingItemsRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*B\n\x1fUpdateGroupMappingItemsMetadata\x12\x1fUpdateGroupMappingItemsResponseB\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.group_mapping_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _GETGROUPMAPPINGREQUEST.fields_by_name['federation_id']._options = None
  _GETGROUPMAPPINGREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._options = None
  _CREATEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._options = None
  _UPDATEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._options = None
  _DELETEGROUPMAPPINGREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEGROUPMAPPINGITEMSREQUEST.fields_by_name['federation_id']._options = None
  _UPDATEGROUPMAPPINGITEMSREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEGROUPMAPPINGITEMSREQUEST.fields_by_name['group_mapping_item_deltas']._options = None
  _UPDATEGROUPMAPPINGITEMSREQUEST.fields_by_name['group_mapping_item_deltas']._serialized_options = b'\202\3101\0061-1000'
  _LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['federation_id']._options = None
  _LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['page_size']._options = None
  _LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['page_token']._options = None
  _LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['filter']._options = None
  _LISTGROUPMAPPINGITEMSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _GROUPMAPPINGSERVICE.methods_by_name['Create']._options = None
  _GROUPMAPPINGSERVICE.methods_by_name['Create']._serialized_options = b'\262\322**\n\032CreateGroupMappingMetadata\022\014GroupMapping'
  _GROUPMAPPINGSERVICE.methods_by_name['Update']._options = None
  _GROUPMAPPINGSERVICE.methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateGroupMappingMetadata\022\014GroupMapping'
  _GROUPMAPPINGSERVICE.methods_by_name['Delete']._options = None
  _GROUPMAPPINGSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*3\n\032DeleteGroupMappingMetadata\022\025google.protobuf.Empty'
  _GROUPMAPPINGSERVICE.methods_by_name['UpdateItems']._options = None
  _GROUPMAPPINGSERVICE.methods_by_name['UpdateItems']._serialized_options = b'\262\322*B\n\037UpdateGroupMappingItemsMetadata\022\037UpdateGroupMappingItemsResponse'
  _globals['_GETGROUPMAPPINGREQUEST']._serialized_start=300
  _globals['_GETGROUPMAPPINGREQUEST']._serialized_end=361
  _globals['_GETGROUPMAPPINGRESPONSE']._serialized_start=363
  _globals['_GETGROUPMAPPINGRESPONSE']._serialized_end=462
  _globals['_CREATEGROUPMAPPINGREQUEST']._serialized_start=464
  _globals['_CREATEGROUPMAPPINGREQUEST']._serialized_end=551
  _globals['_CREATEGROUPMAPPINGMETADATA']._serialized_start=553
  _globals['_CREATEGROUPMAPPINGMETADATA']._serialized_end=604
  _globals['_UPDATEGROUPMAPPINGREQUEST']._serialized_start=607
  _globals['_UPDATEGROUPMAPPINGREQUEST']._serialized_end=737
  _globals['_UPDATEGROUPMAPPINGMETADATA']._serialized_start=739
  _globals['_UPDATEGROUPMAPPINGMETADATA']._serialized_end=790
  _globals['_DELETEGROUPMAPPINGREQUEST']._serialized_start=792
  _globals['_DELETEGROUPMAPPINGREQUEST']._serialized_end=856
  _globals['_DELETEGROUPMAPPINGMETADATA']._serialized_start=858
  _globals['_DELETEGROUPMAPPINGMETADATA']._serialized_end=909
  _globals['_UPDATEGROUPMAPPINGITEMSREQUEST']._serialized_start=912
  _globals['_UPDATEGROUPMAPPINGITEMSREQUEST']._serialized_end=1094
  _globals['_GROUPMAPPINGITEMDELTA']._serialized_start=1097
  _globals['_GROUPMAPPINGITEMDELTA']._serialized_end=1327
  _globals['_GROUPMAPPINGITEMDELTA_ACTION']._serialized_start=1274
  _globals['_GROUPMAPPINGITEMDELTA_ACTION']._serialized_end=1327
  _globals['_UPDATEGROUPMAPPINGITEMSMETADATA']._serialized_start=1329
  _globals['_UPDATEGROUPMAPPINGITEMSMETADATA']._serialized_end=1385
  _globals['_UPDATEGROUPMAPPINGITEMSRESPONSE']._serialized_start=1388
  _globals['_UPDATEGROUPMAPPINGITEMSRESPONSE']._serialized_end=1516
  _globals['_LISTGROUPMAPPINGITEMSREQUEST']._serialized_start=1519
  _globals['_LISTGROUPMAPPINGITEMSREQUEST']._serialized_end=1677
  _globals['_LISTGROUPMAPPINGITEMSRESPONSE']._serialized_start=1680
  _globals['_LISTGROUPMAPPINGITEMSRESPONSE']._serialized_end=1820
  _globals['_GROUPMAPPINGSERVICE']._serialized_start=1823
  _globals['_GROUPMAPPINGSERVICE']._serialized_end=2799
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.cdn.v1.resource_pb2
import yandex.cloud.cdn.v1.resource_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ResourceServiceStub:
    """Provider's resources management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.GetResourceRequest,
        yandex.cloud.cdn.v1.resource_pb2.Resource,
    ]
    """Get client's CDN resource by resource id."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.ListResourcesRequest,
        yandex.cloud.cdn.v1.resource_service_pb2.ListResourcesResponse,
    ]
    """Lists CDN resources."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.CreateResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a CDN resource in the specified folder.

    Creation may take up to 15 minutes.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.UpdateResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified CDN resource.

    The method implements patch behaviour, i.e. only the fields specified in the request are updated in the resource.

    Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge the resource's cache via a
    [CacheService.Purge] request.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.DeleteResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes client's CDN resource."""

    GetProviderCName: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.GetProviderCNameRequest,
        yandex.cloud.cdn.v1.resource_service_pb2.GetProviderCNameResponse,
    ]
    """Get Provider's CNAME (edge endpoint) bind to specified folder id.
    Returns UNIMPLEMENTED error, if provider doesn't support CNAME request.
    """

class ResourceServiceAsyncStub:
    """Provider's resources management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.GetResourceRequest,
        yandex.cloud.cdn.v1.resource_pb2.Resource,
    ]
    """Get client's CDN resource by resource id."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.ListResourcesRequest,
        yandex.cloud.cdn.v1.resource_service_pb2.ListResourcesResponse,
    ]
    """Lists CDN resources."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.CreateResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a CDN resource in the specified folder.

    Creation may take up to 15 minutes.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.UpdateResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified CDN resource.

    The method implements patch behaviour, i.e. only the fields specified in the request are updated in the resource.

    Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge the resource's cache via a
    [CacheService.Purge] request.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.DeleteResourceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes client's CDN resource."""

    GetProviderCName: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.cdn.v1.resource_service_pb2.GetProviderCNameRequest,
        yandex.cloud.cdn.v1.resource_service_pb2.GetProviderCNameResponse,
    ]
    """Get Provider's CNAME (edge endpoint) bind to specified folder id.
    Returns UNIMPLEMENTED error, if provider doesn't support CNAME request.
    """

class ResourceServiceServicer(metaclass=abc.ABCMeta):
    """Provider's resources management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.cdn.v1.resource_service_pb2.GetResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.resource_pb2.Resource, collections.abc.Awaitable[yandex.cloud.cdn.v1.resource_pb2.Resource]]:
        """Get client's CDN resource by resource id."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.cdn.v1.resource_service_pb2.ListResourcesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.resource_service_pb2.ListResourcesResponse, collections.abc.Awaitable[yandex.cloud.cdn.v1.resource_service_pb2.ListResourcesResponse]]:
        """Lists CDN resources."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.cdn.v1.resource_service_pb2.CreateResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a CDN resource in the specified folder.

        Creation may take up to 15 minutes.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.cdn.v1.resource_service_pb2.UpdateResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified CDN resource.

        The method implements patch behaviour, i.e. only the fields specified in the request are updated in the resource.

        Changes may take up to 15 minutes to apply. Afterwards, it is recommended to purge the resource's cache via a
        [CacheService.Purge] request.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.cdn.v1.resource_service_pb2.DeleteResourceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes client's CDN resource."""

    @abc.abstractmethod
    def GetProviderCName(
        self,
        request: yandex.cloud.cdn.v1.resource_service_pb2.GetProviderCNameRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.cdn.v1.resource_service_pb2.GetProviderCNameResponse, collections.abc.Awaitable[yandex.cloud.cdn.v1.resource_service_pb2.GetProviderCNameResponse]]:
        """Get Provider's CNAME (edge endpoint) bind to specified folder id.
        Returns UNIMPLEMENTED error, if provider doesn't support CNAME request.
        """

def add_ResourceServiceServicer_to_server(servicer: ResourceServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.vpc.v1.network_pb2
import yandex.cloud.vpc.v1.network_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class NetworkServiceStub:
    """A set of methods for managing Network resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.GetNetworkRequest,
        yandex.cloud.vpc.v1.network_pb2.Network,
    ]
    """Returns the specified Network resource.

    Get the list of available Network resources by making a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworksRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworksResponse,
    ]
    """Retrieves the list of Network resources in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.CreateNetworkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a network in the specified folder using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.UpdateNetworkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified network.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.DeleteNetworkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified network."""

    ListSubnets: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSubnetsRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSubnetsResponse,
    ]
    """Lists subnets from the specified network."""

    ListSecurityGroups: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSecurityGroupsRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSecurityGroupsResponse,
    ]
    """Lists security groups from the specified network."""

    ListRouteTables: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkRouteTablesRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkRouteTablesResponse,
    ]
    """Lists route tables from the specified network."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkOperationsRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkOperationsResponse,
    ]
    """Lists operations for the specified network."""

    Move: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.MoveNetworkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move network to another folder."""

class NetworkServiceAsyncStub:
    """A set of methods for managing Network resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.GetNetworkRequest,
        yandex.cloud.vpc.v1.network_pb2.Network,
    ]
    """Returns the specified Network resource.

    Get the list of available Network resources by making a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworksRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworksResponse,
    ]
    """Retrieves the list of Network resources in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.CreateNetworkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a network in the specified folder using the data specified in the request.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.UpdateNetworkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified network.
    Method starts an asynchronous operation that can be cancelled while it is in progress.
    """

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.DeleteNetworkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified network."""

    ListSubnets: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSubnetsRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSubnetsResponse,
    ]
    """Lists subnets from the specified network."""

    ListSecurityGroups: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSecurityGroupsRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSecurityGroupsResponse,
    ]
    """Lists security groups from the specified network."""

    ListRouteTables: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkRouteTablesRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkRouteTablesResponse,
    ]
    """Lists route tables from the specified network."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkOperationsRequest,
        yandex.cloud.vpc.v1.network_service_pb2.ListNetworkOperationsResponse,
    ]
    """Lists operations for the specified network."""

    Move: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.vpc.v1.network_service_pb2.MoveNetworkRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Move network to another folder."""

class NetworkServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Network resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.GetNetworkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.network_pb2.Network, collections.abc.Awaitable[yandex.cloud.vpc.v1.network_pb2.Network]]:
        """Returns the specified Network resource.

        Get the list of available Network resources by making a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.ListNetworksRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.network_service_pb2.ListNetworksResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.network_service_pb2.ListNetworksResponse]]:
        """Retrieves the list of Network resources in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.CreateNetworkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a network in the specified folder using the data specified in the request.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.UpdateNetworkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified network.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.DeleteNetworkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified network."""

    @abc.abstractmethod
    def ListSubnets(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSubnetsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSubnetsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSubnetsResponse]]:
        """Lists subnets from the specified network."""

    @abc.abstractmethod
    def ListSecurityGroups(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSecurityGroupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSecurityGroupsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.network_service_pb2.ListNetworkSecurityGroupsResponse]]:
        """Lists security groups from the specified network."""

    @abc.abstractmethod
    def ListRouteTables(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.ListNetworkRouteTablesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.network_service_pb2.ListNetworkRouteTablesResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.network_service_pb2.ListNetworkRouteTablesResponse]]:
        """Lists route tables from the specified network."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.ListNetworkOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.vpc.v1.network_service_pb2.ListNetworkOperationsResponse, collections.abc.Awaitable[yandex.cloud.vpc.v1.network_service_pb2.ListNetworkOperationsResponse]]:
        """Lists operations for the specified network."""

    @abc.abstractmethod
    def Move(
        self,
        request: yandex.cloud.vpc.v1.network_service_pb2.MoveNetworkRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Move network to another folder."""

def add_NetworkServiceServicer_to_server(servicer: NetworkServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.mdb.opensearch.v1.backup_pb2
import yandex.cloud.mdb.opensearch.v1.backup_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BackupServiceStub:
    """A set of methods for managing backups."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.backup_service_pb2.GetBackupRequest,
        yandex.cloud.mdb.opensearch.v1.backup_pb2.Backup,
    ]
    """Returns the specified backup of an OpenSearch cluster."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.backup_service_pb2.ListBackupsRequest,
        yandex.cloud.mdb.opensearch.v1.backup_service_pb2.ListBackupsResponse,
    ]
    """Returns the list of available backups for the specified OpenSearch cluster."""

class BackupServiceAsyncStub:
    """A set of methods for managing backups."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.backup_service_pb2.GetBackupRequest,
        yandex.cloud.mdb.opensearch.v1.backup_pb2.Backup,
    ]
    """Returns the specified backup of an OpenSearch cluster."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.mdb.opensearch.v1.backup_service_pb2.ListBackupsRequest,
        yandex.cloud.mdb.opensearch.v1.backup_service_pb2.ListBackupsResponse,
    ]
    """Returns the list of available backups for the specified OpenSearch cluster."""

class BackupServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing backups."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.mdb.opensearch.v1.backup_service_pb2.GetBackupRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.backup_pb2.Backup, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.backup_pb2.Backup]]:
        """Returns the specified backup of an OpenSearch cluster."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.mdb.opensearch.v1.backup_service_pb2.ListBackupsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.mdb.opensearch.v1.backup_service_pb2.ListBackupsResponse, collections.abc.Awaitable[yandex.cloud.mdb.opensearch.v1.backup_service_pb2.ListBackupsResponse]]:
        """Returns the list of available backups for the specified OpenSearch cluster."""

def add_BackupServiceServicer_to_server(servicer: BackupServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/speechsense/v1/text.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&yandex/cloud/speechsense/v1/text.proto\x12\x1byandex.cloud.speechsense.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"E\n\x0bTextContent\x12\x36\n\x08messages\x18\x01 \x03(\x0b\x32$.yandex.cloud.speechsense.v1.Message\"\x8e\x01\n\x07Message\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x04text\x18\x03 \x01(\x0b\x32(.yandex.cloud.speechsense.v1.TextPayloadH\x00\x42\t\n\x07payload\"\x1b\n\x0bTextPayload\x12\x0c\n\x04text\x18\x01 \x01(\tBy\n\x1fyandex.cloud.api.speechsense.v1B\tTextProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsenseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.speechsense.v1.text_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.speechsense.v1B\tTextProtoZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/speechsense/v1;speechsense'
  _globals['_TEXTCONTENT']._serialized_start=104
  _globals['_TEXTCONTENT']._serialized_end=173
  _globals['_MESSAGE']._serialized_start=176
  _globals['_MESSAGE']._serialized_end=318
  _globals['_TEXTPAYLOAD']._serialized_start=320
  _globals['_TEXTPAYLOAD']._serialized_end=347
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.stream_line_pb2
import yandex.cloud.video.v1.stream_line_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class StreamLineServiceStub:
    """Stream line management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.GetStreamLineRequest,
        yandex.cloud.video.v1.stream_line_pb2.StreamLine,
    ]
    """Returns the specific stream line."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesRequest,
        yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesResponse,
    ]
    """List lines for channel."""

    BatchGet: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesRequest,
        yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesResponse,
    ]
    """Batch get lines for channel."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.CreateStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create stream line."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update stream line."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.DeleteStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete stream line."""

    BatchDelete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.BatchDeleteStreamLinesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete stream lines."""

    PerformAction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.PerformLineActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Perform an action on the line."""

    GetStreamKey: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.GetStreamKeyRequest,
        yandex.cloud.video.v1.stream_line_pb2.PushStreamKey,
    ]
    """Returns unique stream key."""

    UpdateStreamKey: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Change stream key."""

class StreamLineServiceAsyncStub:
    """Stream line management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.GetStreamLineRequest,
        yandex.cloud.video.v1.stream_line_pb2.StreamLine,
    ]
    """Returns the specific stream line."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesRequest,
        yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesResponse,
    ]
    """List lines for channel."""

    BatchGet: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesRequest,
        yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesResponse,
    ]
    """Batch get lines for channel."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.CreateStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create stream line."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update stream line."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.DeleteStreamLineRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete stream line."""

    BatchDelete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.BatchDeleteStreamLinesRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Batch delete stream lines."""

    PerformAction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.PerformLineActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Perform an action on the line."""

    GetStreamKey: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.GetStreamKeyRequest,
        yandex.cloud.video.v1.stream_line_pb2.PushStreamKey,
    ]
    """Returns unique stream key."""

    UpdateStreamKey: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamKeyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Change stream key."""

class StreamLineServiceServicer(metaclass=abc.ABCMeta):
    """Stream line management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.GetStreamLineRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_line_pb2.StreamLine, collections.abc.Awaitable[yandex.cloud.video.v1.stream_line_pb2.StreamLine]]:
        """Returns the specific stream line."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.stream_line_service_pb2.ListStreamLinesResponse]]:
        """List lines for channel."""

    @abc.abstractmethod
    def BatchGet(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.stream_line_service_pb2.BatchGetStreamLinesResponse]]:
        """Batch get lines for channel."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.CreateStreamLineRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create stream line."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamLineRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update stream line."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.DeleteStreamLineRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete stream line."""

    @abc.abstractmethod
    def BatchDelete(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.BatchDeleteStreamLinesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Batch delete stream lines."""

    @abc.abstractmethod
    def PerformAction(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.PerformLineActionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Perform an action on the line."""

    @abc.abstractmethod
    def GetStreamKey(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.GetStreamKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.stream_line_pb2.PushStreamKey, collections.abc.Awaitable[yandex.cloud.video.v1.stream_line_pb2.PushStreamKey]]:
        """Returns unique stream key."""

    @abc.abstractmethod
    def UpdateStreamKey(
        self,
        request: yandex.cloud.video.v1.stream_line_service_pb2.UpdateStreamKeyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Change stream key."""

def add_StreamLineServiceServicer_to_server(servicer: StreamLineServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/test/details.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.common import tag_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_common_dot_tag__pb2
from yandex.cloud.loadtesting.api.v1.test import artifact_settings_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_test_dot_artifact__settings__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/loadtesting/api/v1/test/details.proto\x12$yandex.cloud.loadtesting.api.v1.test\x1a\x30yandex/cloud/loadtesting/api/v1/common/tag.proto\x1a<yandex/cloud/loadtesting/api/v1/test/artifact_settings.proto\x1a\x1dyandex/cloud/validation.proto\"\x89\x02\n\x07\x44\x65tails\x12\x32\n\x04name\x18\x01 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x39\n\x04tags\x18\x03 \x03(\x0b\x32+.yandex.cloud.loadtesting.api.v1.common.Tag\x12\x1c\n\x14logging_log_group_id\x18\x04 \x01(\t\x12Q\n\x11\x61rtifact_settings\x18\x05 \x01(\x0b\x32\x36.yandex.cloud.loadtesting.api.v1.test.ArtifactSettingsBy\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;testb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.test.details_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.loadtesting.api.v1.testZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/test;test'
  _DETAILS.fields_by_name['name']._options = None
  _DETAILS.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _DETAILS.fields_by_name['description']._options = None
  _DETAILS.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_DETAILS']._serialized_start=236
  _globals['_DETAILS']._serialized_end=501
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/workload/oidc/federation_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1.workload.oidc import federation_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_workload_dot_oidc_dot_federation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/iam/v1/workload/oidc/federation_service.proto\x12!yandex.cloud.iam.v1.workload.oidc\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x32yandex/cloud/iam/v1/workload/oidc/federation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\";\n\x14GetFederationRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"x\n\x16ListFederationsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"v\n\x17ListFederationsResponse\x12\x42\n\x0b\x66\x65\x64\x65rations\x18\x01 \x03(\x0b\x32-.yandex.cloud.iam.v1.workload.oidc.Federation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x93\x03\n\x17\x43reateFederationRequest\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04name\x18\x03 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x12%\n\taudiences\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=100\x8a\xc8\x31\x05<=255\x12\x1e\n\x06issuer\x18\x07 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12 \n\x08jwks_url\x18\x08 \x01(\tB\x0e\xe8\xc7\x31\x01\x8a\xc8\x31\x06<=8000\x12V\n\x06labels\x18\t \x03(\x0b\x32\x46.yandex.cloud.iam.v1.workload.oidc.CreateFederationRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18\x43reateFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\"\xa0\x03\n\x17UpdateFederationRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x04name\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x10\n\x08\x64isabled\x18\x05 \x01(\x08\x12%\n\taudiences\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=100\x8a\xc8\x31\x05<=255\x12\x1c\n\x08jwks_url\x18\x07 \x01(\tB\n\x8a\xc8\x31\x06<=8000\x12V\n\x06labels\x18\x08 \x03(\x0b\x32\x46.yandex.cloud.iam.v1.workload.oidc.UpdateFederationRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"1\n\x18UpdateFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t\">\n\x17\x44\x65leteFederationRequest\x12#\n\rfederation_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"1\n\x18\x44\x65leteFederationMetadata\x12\x15\n\rfederation_id\x18\x01 \x01(\t2\xd7\x07\n\x11\x46\x65\x64\x65rationService\x12\xa8\x01\n\x03Get\x12\x37.yandex.cloud.iam.v1.workload.oidc.GetFederationRequest\x1a-.yandex.cloud.iam.v1.workload.oidc.Federation\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/iam/v1/workload/oidc/federations/{federation_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.iam.v1.workload.oidc.ListFederationsRequest\x1a:.yandex.cloud.iam.v1.workload.oidc.ListFederationsResponse\")\x82\xd3\xe4\x93\x02#\x12!/iam/v1/workload/oidc/federations\x12\xbf\x01\n\x06\x43reate\x12:.yandex.cloud.iam.v1.workload.oidc.CreateFederationRequest\x1a!.yandex.cloud.operation.Operation\"V\xb2\xd2*&\n\x18\x43reateFederationMetadata\x12\nFederation\x82\xd3\xe4\x93\x02&\"!/iam/v1/workload/oidc/federations:\x01*\x12\xcf\x01\n\x06Update\x12:.yandex.cloud.iam.v1.workload.oidc.UpdateFederationRequest\x1a!.yandex.cloud.operation.Operation\"f\xb2\xd2*&\n\x18UpdateFederationMetadata\x12\nFederation\x82\xd3\xe4\x93\x02\x36\x32\x31/iam/v1/workload/oidc/federations/{federation_id}:\x01*\x12\xd7\x01\n\x06\x44\x65lete\x12:.yandex.cloud.iam.v1.workload.oidc.DeleteFederationRequest\x1a!.yandex.cloud.operation.Operation\"n\xb2\xd2*1\n\x18\x44\x65leteFederationMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x33*1/iam/v1/workload/oidc/federations/{federation_id}Bs\n%yandex.cloud.api.iam.v1.workload.oidcZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload/oidc;oidcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.workload.oidc.federation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.iam.v1.workload.oidcZJgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload/oidc;oidc'
  _GETFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
  _GETFEDERATIONREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFEDERATIONSREQUEST.fields_by_name['folder_id']._options = None
  _LISTFEDERATIONSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFEDERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTFEDERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTFEDERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTFEDERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _CREATEFEDERATIONREQUEST_LABELSENTRY._options = None
  _CREATEFEDERATIONREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATEFEDERATIONREQUEST.fields_by_name['folder_id']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEFEDERATIONREQUEST.fields_by_name['name']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATEFEDERATIONREQUEST.fields_by_name['description']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEFEDERATIONREQUEST.fields_by_name['audiences']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['audiences']._serialized_options = b'\202\3101\005<=100\212\3101\005<=255'
  _CREATEFEDERATIONREQUEST.fields_by_name['issuer']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['issuer']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _CREATEFEDERATIONREQUEST.fields_by_name['jwks_url']._options = None
  _CREATEFEDERATIONREQUEST.fields_by_name['jwks_url']._serialized_options = b'\350\3071\001\212\3101\006<=8000'
  _UPDATEFEDERATIONREQUEST_LABELSENTRY._options = None
  _UPDATEFEDERATIONREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEFEDERATIONREQUEST.fields_by_name['name']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEFEDERATIONREQUEST.fields_by_name['description']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEFEDERATIONREQUEST.fields_by_name['audiences']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['audiences']._serialized_options = b'\202\3101\005<=100\212\3101\005<=255'
  _UPDATEFEDERATIONREQUEST.fields_by_name['jwks_url']._options = None
  _UPDATEFEDERATIONREQUEST.fields_by_name['jwks_url']._serialized_options = b'\212\3101\006<=8000'
  _DELETEFEDERATIONREQUEST.fields_by_name['federation_id']._options = None
  _DELETEFEDERATIONREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _FEDERATIONSERVICE.methods_by_name['Get']._options = None
  _FEDERATIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0023\0221/iam/v1/workload/oidc/federations/{federation_id}'
  _FEDERATIONSERVICE.methods_by_name['List']._options = None
  _FEDERATIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002#\022!/iam/v1/workload/oidc/federations'
  _FEDERATIONSERVICE.methods_by_name['Create']._options = None
  _FEDERATIONSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateFederationMetadata\022\nFederation\202\323\344\223\002&\"!/iam/v1/workload/oidc/federations:\001*'
  _FEDERATIONSERVICE.methods_by_name['Update']._options = None
  _FEDERATIONSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateFederationMetadata\022\nFederation\202\323\344\223\002621/iam/v1/workload/oidc/federations/{federation_id}:\001*'
  _FEDERATIONSERVICE.methods_by_name['Delete']._options = None
  _FEDERATIONSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteFederationMetadata\022\025google.protobuf.Empty\202\323\344\223\0023*1/iam/v1/workload/oidc/federations/{federation_id}'
  _globals['_GETFEDERATIONREQUEST']._serialized_start=318
  _globals['_GETFEDERATIONREQUEST']._serialized_end=377
  _globals['_LISTFEDERATIONSREQUEST']._serialized_start=379
  _globals['_LISTFEDERATIONSREQUEST']._serialized_end=499
  _globals['_LISTFEDERATIONSRESPONSE']._serialized_start=501
  _globals['_LISTFEDERATIONSRESPONSE']._serialized_end=619
  _globals['_CREATEFEDERATIONREQUEST']._serialized_start=622
  _globals['_CREATEFEDERATIONREQUEST']._serialized_end=1025
  _globals['_CREATEFEDERATIONREQUEST_LABELSENTRY']._serialized_start=980
  _globals['_CREATEFEDERATIONREQUEST_LABELSENTRY']._serialized_end=1025
  _globals['_CREATEFEDERATIONMETADATA']._serialized_start=1027
  _globals['_CREATEFEDERATIONMETADATA']._serialized_end=1076
  _globals['_UPDATEFEDERATIONREQUEST']._serialized_start=1079
  _globals['_UPDATEFEDERATIONREQUEST']._serialized_end=1495
  _globals['_UPDATEFEDERATIONREQUEST_LABELSENTRY']._serialized_start=980
  _globals['_UPDATEFEDERATIONREQUEST_LABELSENTRY']._serialized_end=1025
  _globals['_UPDATEFEDERATIONMETADATA']._serialized_start=1497
  _globals['_UPDATEFEDERATIONMETADATA']._serialized_end=1546
  _globals['_DELETEFEDERATIONREQUEST']._serialized_start=1548
  _globals['_DELETEFEDERATIONREQUEST']._serialized_end=1610
  _globals['_DELETEFEDERATIONMETADATA']._serialized_start=1612
  _globals['_DELETEFEDERATIONMETADATA']._serialized_end=1661
  _globals['_FEDERATIONSERVICE']._serialized_start=1664
  _globals['_FEDERATIONSERVICE']._serialized_end=2647
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/resourcemanager/v1/cloud_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.resourcemanager.v1 import cloud_pb2 as yandex_dot_cloud_dot_resourcemanager_dot_v1_dot_cloud__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/resourcemanager/v1/cloud_service.proto\x12\x1fyandex.cloud.resourcemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a+yandex/cloud/resourcemanager/v1/cloud.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"1\n\x0fGetCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x91\x01\n\x11ListCloudsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12!\n\x0forganization_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"e\n\x12ListCloudsResponse\x12\x36\n\x06\x63louds\x18\x01 \x03(\x0b\x32&.yandex.cloud.resourcemanager.v1.Cloud\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xce\x02\n\x12\x43reateCloudRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04name\x18\x02 \x01(\tB%\xe8\xc7\x31\x01\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x04 \x03(\x0b\x32?.yandex.cloud.resourcemanager.v1.CreateCloudRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13\x43reateCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\"{\n\x1aListCloudOperationsRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"m\n\x1bListCloudOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf6\x02\n\x12UpdateCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x31\n\x04name\x18\x03 \x01(\tB#\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x8c\x01\n\x06labels\x18\x05 \x03(\x0b\x32?.yandex.cloud.resourcemanager.v1.UpdateCloudRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\'\n\x13UpdateCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\"f\n\x12\x44\x65leteCloudRequest\x12\x1e\n\x08\x63loud_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x30\n\x0c\x64\x65lete_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xa1\x01\n\x13\x44\x65leteCloudMetadata\x12\x10\n\x08\x63loud_id\x18\x01 \x01(\t\x12\x30\n\x0c\x64\x65lete_after\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x63\x61ncelled_by\x18\x03 \x01(\t\x12\x30\n\x0c\x63\x61ncelled_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xe8\r\n\x0c\x43loudService\x12\x8f\x01\n\x03Get\x12\x30.yandex.cloud.resourcemanager.v1.GetCloudRequest\x1a&.yandex.cloud.resourcemanager.v1.Cloud\".\x82\xd3\xe4\x93\x02(\x12&/resource-manager/v1/clouds/{cloud_id}\x12\x94\x01\n\x04List\x12\x32.yandex.cloud.resourcemanager.v1.ListCloudsRequest\x1a\x33.yandex.cloud.resourcemanager.v1.ListCloudsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/resource-manager/v1/clouds\x12\xa8\x01\n\x06\x43reate\x12\x33.yandex.cloud.resourcemanager.v1.CreateCloudRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*\x1c\n\x13\x43reateCloudMetadata\x12\x05\x43loud\x82\xd3\xe4\x93\x02 \"\x1b/resource-manager/v1/clouds:\x01*\x12\xb3\x01\n\x06Update\x12\x33.yandex.cloud.resourcemanager.v1.UpdateCloudRequest\x1a!.yandex.cloud.operation.Operation\"Q\xb2\xd2*\x1c\n\x13UpdateCloudMetadata\x12\x05\x43loud\x82\xd3\xe4\x93\x02+2&/resource-manager/v1/clouds/{cloud_id}:\x01*\x12\xc0\x01\n\x06\x44\x65lete\x12\x33.yandex.cloud.resourcemanager.v1.DeleteCloudRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*,\n\x13\x44\x65leteCloudMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02(*&/resource-manager/v1/clouds/{cloud_id}\x12\xc6\x01\n\x0eListOperations\x12;.yandex.cloud.resourcemanager.v1.ListCloudOperationsRequest\x1a<.yandex.cloud.resourcemanager.v1.ListCloudOperationsResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/resource-manager/v1/clouds/{cloud_id}/operations\x12\xbb\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"D\x82\xd3\xe4\x93\x02>\x12</resource-manager/v1/clouds/{resource_id}:listAccessBindings\x12\xfa\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02@\";/resource-manager/v1/clouds/{resource_id}:setAccessBindings:\x01*\x12\x86\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x98\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x43\">/resource-manager/v1/clouds/{resource_id}:updateAccessBindings:\x01*Bz\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.resourcemanager.v1.cloud_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.resourcemanager.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/resourcemanager/v1;resourcemanager'
  _GETCLOUDREQUEST.fields_by_name['cloud_id']._options = None
  _GETCLOUDREQUEST.fields_by_name['cloud_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLOUDSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLOUDSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLOUDSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLOUDSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _LISTCLOUDSREQUEST.fields_by_name['filter']._options = None
  _LISTCLOUDSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTCLOUDSREQUEST.fields_by_name['organization_id']._options = None
  _LISTCLOUDSREQUEST.fields_by_name['organization_id']._serialized_options = b'\212\3101\004<=50'
  _CREATECLOUDREQUEST_LABELSENTRY._options = None
  _CREATECLOUDREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECLOUDREQUEST.fields_by_name['organization_id']._options = None
  _CREATECLOUDREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECLOUDREQUEST.fields_by_name['name']._options = None
  _CREATECLOUDREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]'
  _CREATECLOUDREQUEST.fields_by_name['description']._options = None
  _CREATECLOUDREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATECLOUDREQUEST.fields_by_name['labels']._options = None
  _CREATECLOUDREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _LISTCLOUDOPERATIONSREQUEST.fields_by_name['cloud_id']._options = None
  _LISTCLOUDOPERATIONSREQUEST.fields_by_name['cloud_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCLOUDOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCLOUDOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCLOUDOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCLOUDOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _UPDATECLOUDREQUEST_LABELSENTRY._options = None
  _UPDATECLOUDREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECLOUDREQUEST.fields_by_name['cloud_id']._options = None
  _UPDATECLOUDREQUEST.fields_by_name['cloud_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECLOUDREQUEST.fields_by_name['name']._options = None
  _UPDATECLOUDREQUEST.fields_by_name['name']._serialized_options = b'\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATECLOUDREQUEST.fields_by_name['description']._options = None
  _UPDATECLOUDREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATECLOUDREQUEST.fields_by_name['labels']._options = None
  _UPDATECLOUDREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _DELETECLOUDREQUEST.fields_by_name['cloud_id']._options = None
  _DELETECLOUDREQUEST.fields_by_name['cloud_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CLOUDSERVICE.methods_by_name['Get']._options = None
  _CLOUDSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002(\022&/resource-manager/v1/clouds/{cloud_id}'
  _CLOUDSERVICE.methods_by_name['List']._options = None
  _CLOUDSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\035\022\033/resource-manager/v1/clouds'
  _CLOUDSERVICE.methods_by_name['Create']._options = None
  _CLOUDSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\034\n\023CreateCloudMetadata\022\005Cloud\202\323\344\223\002 \"\033/resource-manager/v1/clouds:\001*'
  _CLOUDSERVICE.methods_by_name['Update']._options = None
  _CLOUDSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\034\n\023UpdateCloudMetadata\022\005Cloud\202\323\344\223\002+2&/resource-manager/v1/clouds/{cloud_id}:\001*'
  _CLOUDSERVICE.methods_by_name['Delete']._options = None
  _CLOUDSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*,\n\023DeleteCloudMetadata\022\025google.protobuf.Empty\202\323\344\223\002(*&/resource-manager/v1/clouds/{cloud_id}'
  _CLOUDSERVICE.methods_by_name['ListOperations']._options = None
  _CLOUDSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\0023\0221/resource-manager/v1/clouds/{cloud_id}/operations'
  _CLOUDSERVICE.methods_by_name['ListAccessBindings']._options = None
  _CLOUDSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002>\022</resource-manager/v1/clouds/{resource_id}:listAccessBindings'
  _CLOUDSERVICE.methods_by_name['SetAccessBindings']._options = None
  _CLOUDSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002@\";/resource-manager/v1/clouds/{resource_id}:setAccessBindings:\001*'
  _CLOUDSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _CLOUDSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002C\">/resource-manager/v1/clouds/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETCLOUDREQUEST']._serialized_start=369
  _globals['_GETCLOUDREQUEST']._serialized_end=418
  _globals['_LISTCLOUDSREQUEST']._serialized_start=421
  _globals['_LISTCLOUDSREQUEST']._serialized_end=566
  _globals['_LISTCLOUDSRESPONSE']._serialized_start=568
  _globals['_LISTCLOUDSRESPONSE']._serialized_end=669
  _globals['_CREATECLOUDREQUEST']._serialized_start=672
  _globals['_CREATECLOUDREQUEST']._serialized_end=1006
  _globals['_CREATECLOUDREQUEST_LABELSENTRY']._serialized_start=961
  _globals['_CREATECLOUDREQUEST_LABELSENTRY']._serialized_end=1006
  _globals['_CREATECLOUDMETADATA']._serialized_start=1008
  _globals['_CREATECLOUDMETADATA']._serialized_end=1047
  _globals['_LISTCLOUDOPERATIONSREQUEST']._serialized_start=1049
  _globals['_LISTCLOUDOPERATIONSREQUEST']._serialized_end=1172
  _globals['_LISTCLOUDOPERATIONSRESPONSE']._serialized_start=1174
  _globals['_LISTCLOUDOPERATIONSRESPONSE']._serialized_end=1283
  _globals['_UPDATECLOUDREQUEST']._serialized_start=1286
  _globals['_UPDATECLOUDREQUEST']._serialized_end=1660
  _globals['_UPDATECLOUDREQUEST_LABELSENTRY']._serialized_start=961
  _globals['_UPDATECLOUDREQUEST_LABELSENTRY']._serialized_end=1006
  _globals['_UPDATECLOUDMETADATA']._serialized_start=1662
  _globals['_UPDATECLOUDMETADATA']._serialized_end=1701
  _globals['_DELETECLOUDREQUEST']._serialized_start=1703
  _globals['_DELETECLOUDREQUEST']._serialized_end=1805
  _globals['_DELETECLOUDMETADATA']._serialized_start=1808
  _globals['_DELETECLOUDMETADATA']._serialized_end=1969
  _globals['_CLOUDSERVICE']._serialized_start=1972
  _globals['_CLOUDSERVICE']._serialized_end=3740
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/runs/run_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.common import common_pb2 as yandex_dot_cloud_dot_ai_dot_common_dot_common__pb2
from yandex.cloud.ai.assistants.v1 import common_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_common__pb2
from yandex.cloud.ai.assistants.v1.threads import message_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_threads_dot_message__pb2
from yandex.cloud.ai.assistants.v1.runs import run_pb2 as yandex_dot_cloud_dot_ai_dot_assistants_dot_v1_dot_runs_dot_run__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/ai/assistants/v1/runs/run_service.proto\x12\"yandex.cloud.ai.assistants.v1.runs\x1a#yandex/cloud/ai/common/common.proto\x1a*yandex/cloud/ai/assistants/v1/common.proto\x1a\x33yandex/cloud/ai/assistants/v1/threads/message.proto\x1a,yandex/cloud/ai/assistants/v1/runs/run.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xe0\x03\n\x10\x43reateRunRequest\x12\x1a\n\x0c\x61ssistant_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x17\n\tthread_id\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12P\n\x06labels\x18\x03 \x03(\x0b\x32@.yandex.cloud.ai.assistants.v1.runs.CreateRunRequest.LabelsEntry\x12O\n\x13\x61\x64\x64itional_messages\x18\x04 \x03(\x0b\x32\x32.yandex.cloud.ai.assistants.v1.threads.MessageData\x12`\n custom_prompt_truncation_options\x18\x05 \x01(\x0b\x32\x36.yandex.cloud.ai.assistants.v1.PromptTruncationOptions\x12S\n\x19\x63ustom_completion_options\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.CompletionOptions\x12\x0e\n\x06stream\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"_\n\x10ListenRunRequest\x12\x14\n\x06run_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x10\x65vents_start_idx\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"%\n\rGetRunRequest\x12\x14\n\x06run_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"4\n\x19GetLastRunByThreadRequest\x12\x17\n\tthread_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"Q\n\x0fListRunsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\"b\n\x10ListRunsResponse\x12\x35\n\x04runs\x18\x01 \x03(\x0b\x32\'.yandex.cloud.ai.assistants.v1.runs.Run\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"K\n\x0cStreamCursor\x12\x19\n\x11\x63urrent_event_idx\x18\x01 \x01(\x03\x12 \n\x18num_user_events_received\x18\x02 \x01(\x03\"\xd4\x03\n\x0bStreamEvent\x12M\n\nevent_type\x18\x01 \x01(\x0e\x32\x39.yandex.cloud.ai.assistants.v1.runs.StreamEvent.EventType\x12G\n\rstream_cursor\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.ai.assistants.v1.runs.StreamCursor\x12.\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x1d.yandex.cloud.ai.common.ErrorH\x00\x12P\n\x0fpartial_message\x18\x04 \x01(\x0b\x32\x35.yandex.cloud.ai.assistants.v1.threads.MessageContentH\x00\x12K\n\x11\x63ompleted_message\x18\x05 \x01(\x0b\x32..yandex.cloud.ai.assistants.v1.threads.MessageH\x00\"Q\n\tEventType\x12\x1a\n\x16\x45VENT_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fPARTIAL_MESSAGE\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x08\n\x04\x44ONE\x10\x03\x42\x0b\n\tEventData2\xee\x05\n\nRunService\x12\x87\x01\n\x06\x43reate\x12\x34.yandex.cloud.ai.assistants.v1.runs.CreateRunRequest\x1a\'.yandex.cloud.ai.assistants.v1.runs.Run\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/assistants/v1/runs:\x01*\x12\x95\x01\n\x06Listen\x12\x34.yandex.cloud.ai.assistants.v1.runs.ListenRunRequest\x1a/.yandex.cloud.ai.assistants.v1.runs.StreamEvent\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/assistants/v1/runs/listen0\x01\x12\x87\x01\n\x03Get\x12\x31.yandex.cloud.ai.assistants.v1.runs.GetRunRequest\x1a\'.yandex.cloud.ai.assistants.v1.runs.Run\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/assistants/v1/runs/{run_id}\x12\xa2\x01\n\x0fGetLastByThread\x12=.yandex.cloud.ai.assistants.v1.runs.GetLastRunByThreadRequest\x1a\'.yandex.cloud.ai.assistants.v1.runs.Run\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/assistants/v1/runs:getByThread\x12\x8e\x01\n\x04List\x12\x33.yandex.cloud.ai.assistants.v1.runs.ListRunsRequest\x1a\x34.yandex.cloud.ai.assistants.v1.runs.ListRunsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/assistants/v1/runsBu\n&yandex.cloud.api.ai.assistants.v1.runsZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/runs;runsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.runs.run_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.ai.assistants.v1.runsZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/runs;runs'
  _CREATERUNREQUEST_LABELSENTRY._options = None
  _CREATERUNREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATERUNREQUEST.fields_by_name['assistant_id']._options = None
  _CREATERUNREQUEST.fields_by_name['assistant_id']._serialized_options = b'\350\3071\001'
  _CREATERUNREQUEST.fields_by_name['thread_id']._options = None
  _CREATERUNREQUEST.fields_by_name['thread_id']._serialized_options = b'\350\3071\001'
  _LISTENRUNREQUEST.fields_by_name['run_id']._options = None
  _LISTENRUNREQUEST.fields_by_name['run_id']._serialized_options = b'\350\3071\001'
  _GETRUNREQUEST.fields_by_name['run_id']._options = None
  _GETRUNREQUEST.fields_by_name['run_id']._serialized_options = b'\350\3071\001'
  _GETLASTRUNBYTHREADREQUEST.fields_by_name['thread_id']._options = None
  _GETLASTRUNBYTHREADREQUEST.fields_by_name['thread_id']._serialized_options = b'\350\3071\001'
  _LISTRUNSREQUEST.fields_by_name['folder_id']._options = None
  _LISTRUNSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _RUNSERVICE.methods_by_name['Create']._options = None
  _RUNSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\030\"\023/assistants/v1/runs:\001*'
  _RUNSERVICE.methods_by_name['Listen']._options = None
  _RUNSERVICE.methods_by_name['Listen']._serialized_options = b'\202\323\344\223\002\034\022\032/assistants/v1/runs/listen'
  _RUNSERVICE.methods_by_name['Get']._options = None
  _RUNSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\036\022\034/assistants/v1/runs/{run_id}'
  _RUNSERVICE.methods_by_name['GetLastByThread']._options = None
  _RUNSERVICE.methods_by_name['GetLastByThread']._serialized_options = b'\202\323\344\223\002!\022\037/assistants/v1/runs:getByThread'
  _RUNSERVICE.methods_by_name['List']._options = None
  _RUNSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/assistants/v1/runs'
  _globals['_CREATERUNREQUEST']._serialized_start=366
  _globals['_CREATERUNREQUEST']._serialized_end=846
  _globals['_CREATERUNREQUEST_LABELSENTRY']._serialized_start=801
  _globals['_CREATERUNREQUEST_LABELSENTRY']._serialized_end=846
  _globals['_LISTENRUNREQUEST']._serialized_start=848
  _globals['_LISTENRUNREQUEST']._serialized_end=943
  _globals['_GETRUNREQUEST']._serialized_start=945
  _globals['_GETRUNREQUEST']._serialized_end=982
  _globals['_GETLASTRUNBYTHREADREQUEST']._serialized_start=984
  _globals['_GETLASTRUNBYTHREADREQUEST']._serialized_end=1036
  _globals['_LISTRUNSREQUEST']._serialized_start=1038
  _globals['_LISTRUNSREQUEST']._serialized_end=1119
  _globals['_LISTRUNSRESPONSE']._serialized_start=1121
  _globals['_LISTRUNSRESPONSE']._serialized_end=1219
  _globals['_STREAMCURSOR']._serialized_start=1221
  _globals['_STREAMCURSOR']._serialized_end=1296
  _globals['_STREAMEVENT']._serialized_start=1299
  _globals['_STREAMEVENT']._serialized_end=1767
  _globals['_STREAMEVENT_EVENTTYPE']._serialized_start=1673
  _globals['_STREAMEVENT_EVENTTYPE']._serialized_end=1754
  _globals['_RUNSERVICE']._serialized_start=1770
  _globals['_RUNSERVICE']._serialized_end=2520
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing
import yandex.cloud.ai.vision.v2.image_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Label(google.protobuf.message.Message):
    """Description of single label"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """   Label name"""
    description: builtins.str
    """   human readable description of label"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "name", b"name"]) -> None: ...

global___Label = Label

@typing.final
class ClassAnnotation(google.protobuf.message.Message):
    """Image annotation for specific label"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LABEL_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    confidence: builtins.float
    """   confidence for each label"""
    @property
    def label(self) -> global___Label:
        """   list of annotated labels"""

    def __init__(
        self,
        *,
        label: global___Label | None = ...,
        confidence: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "label", b"label"]) -> None: ...

global___ClassAnnotation = ClassAnnotation

@typing.final
class ClassifierSpecification(google.protobuf.message.Message):
    """Specification of model used for annotation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ClassificationType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ClassificationTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ClassifierSpecification._ClassificationType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CLASSIFICATION_TYPE_UNSPECIFIED: ClassifierSpecification._ClassificationType.ValueType  # 0
        MULTI_LABEL: ClassifierSpecification._ClassificationType.ValueType  # 1
        MULTI_CLASS: ClassifierSpecification._ClassificationType.ValueType  # 2

    class ClassificationType(_ClassificationType, metaclass=_ClassificationTypeEnumTypeWrapper): ...
    CLASSIFICATION_TYPE_UNSPECIFIED: ClassifierSpecification.ClassificationType.ValueType  # 0
    MULTI_LABEL: ClassifierSpecification.ClassificationType.ValueType  # 1
    MULTI_CLASS: ClassifierSpecification.ClassificationType.ValueType  # 2

    LABELS_FIELD_NUMBER: builtins.int
    CLASSIFICATION_TYPE_FIELD_NUMBER: builtins.int
    classification_type: global___ClassifierSpecification.ClassificationType.ValueType
    """   type of annotation: exclusive (multi-class) or non-exclusive (multi-label)"""
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Label]:
        """ List of labels, annotated by service"""

    def __init__(
        self,
        *,
        labels: collections.abc.Iterable[global___Label] | None = ...,
        classification_type: global___ClassifierSpecification.ClassificationType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["classification_type", b"classification_type", "labels", b"labels"]) -> None: ...

global___ClassifierSpecification = ClassifierSpecification

@typing.final
class AnnotationResponse(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    CLASSIFIER_SPECIFICATION_FIELD_NUMBER: builtins.int
    ANNOTATIONS_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """ internal service requestId"""
    @property
    def classifier_specification(self) -> global___ClassifierSpecification:
        """ class specification"""

    @property
    def annotations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClassAnnotation]:
        """   annotations for each class"""

    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        classifier_specification: global___ClassifierSpecification | None = ...,
        annotations: collections.abc.Iterable[global___ClassAnnotation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["classifier_specification", b"classifier_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["annotations", b"annotations", "classifier_specification", b"classifier_specification", "request_id", b"request_id"]) -> None: ...

global___AnnotationResponse = AnnotationResponse

@typing.final
class AnnotationRequest(google.protobuf.message.Message):
    """request for annotation"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IMAGE_FIELD_NUMBER: builtins.int
    @property
    def image(self) -> yandex.cloud.ai.vision.v2.image_pb2.Image:
        """   image to annotate"""

    def __init__(
        self,
        *,
        image: yandex.cloud.ai.vision.v2.image_pb2.Image | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["image", b"image"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["image", b"image"]) -> None: ...

global___AnnotationRequest = AnnotationRequest
